@@ -685,7 +685,8 @@ scatterPlot <- function(mydata,
                       }
 
 
-                      if (mod.line) {
+                      if (mod.line && group.number == 1) {
+
                           panel.abline(a = c(0, 0.5), lty = 5)
                           panel.abline(a = c(0, 2), lty = 5)
                           panel.abline(a = c(0, 1), lty = 1)
@@ -985,6 +986,8 @@ panel.linear <- function (x, y, form = y ~ x, method = "loess", x.nam, y.nam, ..
                           subscripts, group.number, group.value, type, col.line,
                           col.symbol, fill, pch, cex, font, fontface, fontfamily)
 {
+    ## get rid of R check annoyances
+    plot.line = NULL
 
 
     thedata <- data.frame(x = x, y = y)
